@@ -1224,6 +1224,20 @@ gi_marshalling_tests_array_in (const gint *ints, gint length)
     g_assert(ints[3] == 2);
 }
 
+/**
+ * gi_marshalling_tests_array_uint8_in:
+ * @chars: (array length=length):
+ */
+void
+gi_marshalling_tests_array_uint8_in (const guint8 *chars, gint length)
+{
+    g_assert(length == 4);
+    g_assert(chars[0] == 'a');
+    g_assert(chars[1] == 'b');
+    g_assert(chars[2] == 'c');
+    g_assert(chars[3] == 'd');
+}
+
 /**
  * gi_marshalling_tests_array_out:
  * @ints: (out) (array length=length) (transfer none):
@@ -1309,6 +1323,20 @@ gi_marshalling_tests_array_zero_terminated_inout (gchar ***utf8s)
     *utf8s = values;
 }
 
+/**
+ * gi_marshalling_tests_array_gvariant_in:
+ * @variants: (array zero-terminated=1) (transfer none):
+ */
+GVariant **
+gi_marshalling_tests_array_gvariant_in (GVariant **variants)
+{
+    g_assert (variants != NULL);
+    g_assert_cmpint (g_variant_get_int32 (variants[0]), ==, 27);
+    g_assert_cmpstr (g_variant_get_string (variants[1], NULL), ==, "Hello");
+    g_assert (variants[2] == NULL);
+
+    return variants;
+}
 
 /**
  * gi_marshalling_tests_garray_int_none_return:
@@ -2649,7 +2677,7 @@ gi_marshalling_tests_boxed_struct_get_type (void)
 GIMarshallingTestsBoxedStruct *
 gi_marshalling_tests_boxed_struct_new (void)
 {
-    return g_slice_new (GIMarshallingTestsBoxedStruct);
+    return g_slice_new0 (GIMarshallingTestsBoxedStruct);
 }
 
 /**
@@ -3169,6 +3197,27 @@ gi_marshalling_tests_test_interface_test_int8_in (GIMarshallingTestsInterface *t
 }
 
 
+static void
+gi_marshalling_tests_interface2_class_init(void *g_iface)
+{
+}
+
+GType
+gi_marshalling_tests_interface2_get_type(void)
+{
+    static GType type = 0;
+    if (type == 0) {
+        type = g_type_register_static_simple (G_TYPE_INTERFACE,
+                                              "GIMarshallingTestsInterface2",
+                                              sizeof (GIMarshallingTestsInterface2Iface),
+                                              (GClassInitFunc) gi_marshalling_tests_interface2_class_init,
+                                              0, NULL, 0);
+    }
+
+    return type;
+}
+
+
 /**
  * gi_marshalling_tests_int_out_out:
  * @int0: (out):
@@ -3192,6 +3241,17 @@ gi_marshalling_tests_int_return_out (gint *int_)
     return 6;
 }
 
+/* GError */
+
+void
+gi_marshalling_tests_gerror(GError **error)
+{
+    GQuark quark = g_quark_from_static_string(GI_MARSHALLING_TESTS_CONSTANT_GERROR_DOMAIN);
+    g_set_error_literal(error,
+                        quark,
+                        GI_MARSHALLING_TESTS_CONSTANT_GERROR_CODE,
+                        GI_MARSHALLING_TESTS_CONSTANT_GERROR_MESSAGE);
+}
 
 static GIMarshallingTestsOverridesStruct *
 gi_marshalling_tests_overrides_struct_copy (GIMarshallingTestsOverridesStruct *struct_)
