@@ -281,6 +281,8 @@ const gint *gi_marshalling_tests_array_return (gint *length);
 
 void gi_marshalling_tests_array_in (const gint *ints, gint length);
 
+void gi_marshalling_tests_array_uint8_in (const guint8 *chars, gint length);
+
 void gi_marshalling_tests_array_out (gint **ints, gint *length);
 
 void gi_marshalling_tests_array_inout (gint **ints, gint *length);
@@ -295,6 +297,8 @@ void gi_marshalling_tests_array_zero_terminated_out (gchar ***utf8s);
 
 void gi_marshalling_tests_array_zero_terminated_inout (gchar ***utf8s);
 
+GVariant **gi_marshalling_tests_array_gvariant_in (GVariant **variants);
+
 
 /* GArray */
 
@@ -421,6 +425,12 @@ typedef enum
   GI_MARSHALLING_TESTS_ENUM_VALUE3 = 42
 } GIMarshallingTestsEnum;
 
+typedef enum
+{
+  GI_MARSHALLING_TESTS_SECOND_ENUM_SECONDVALUE1,
+  GI_MARSHALLING_TESTS_SECOND_ENUM_SECONDVALUE2,
+} GIMarshallingTestsSecondEnum;
+
 GIMarshallingTestsEnum gi_marshalling_tests_enum_returnv (void);
 
 void gi_marshalling_tests_enum_in (GIMarshallingTestsEnum enum_);
@@ -664,6 +674,29 @@ void gi_marshalling_tests_interface_test_int8_in (GIMarshallingTestsInterface *s
 
 void gi_marshalling_tests_test_interface_test_int8_in (GIMarshallingTestsInterface *test_iface, gint8 in);
 
+/* GIMarshallingTestsInterface2 allows us testing vfunc clashes when a class'
+   vfunc implementation ambiguously relates to its prototype */
+
+#define GI_MARSHALLING_TESTS_TYPE_INTERFACE2              (gi_marshalling_tests_interface2_get_type ())
+#define GI_MARSHALLING_TESTS_INTERFACE2(object)           (G_TYPE_CHECK_INSTANCE_CAST ((object), GI_MARSHALLING_TESTS_TYPE_INTERFACE2, GIMarshallingTestsInterface2))
+#define GI_MARSHALLING_TESTS_IS_INTERFACE2(object)        (G_TYPE_CHECK_INSTANCE_TYPE ((object), GI_MARSHALLING_TESTS_TYPE_INTERFACE2))
+#define GI_MARSHALLING_TESTS_INTERFACE2_GET_IFACE(obj)    (G_TYPE_INSTANCE_GET_INTERFACE2 ((obj), GI_MARSHALLING_TESTS_TYPE_INTERFACE2, GIMarshallingTestsInterface2Iface))
+
+typedef struct _GIMarshallingTestsInterface2 GIMarshallingTestsInterface2;
+typedef struct _GIMarshallingTestsInterface2Iface GIMarshallingTestsInterface2Iface;
+
+struct _GIMarshallingTestsInterface2Iface {
+    GTypeInterface base_iface;
+
+    /**
+     * GIMarshallingTestsInterface2Iface::test_int8_in:
+     * @in: (in):
+     */
+    void (* test_int8_in) (GIMarshallingTestsInterface2 *self, gint8 in);
+};
+
+GType gi_marshalling_tests_interface2_get_type (void) G_GNUC_CONST;
+
 
 /* Multiple output arguments */
 
@@ -673,6 +706,14 @@ gint gi_marshalling_tests_int_return_out (gint *int_);
 void gi_marshalling_tests_utf8_full_out_out (gchar **utf80, gchar **utf82);
 
 
+/* GError */
+
+#define GI_MARSHALLING_TESTS_CONSTANT_GERROR_DOMAIN "gi-marshalling-tests-gerror-domain"
+#define GI_MARSHALLING_TESTS_CONSTANT_GERROR_CODE 5
+#define GI_MARSHALLING_TESTS_CONSTANT_GERROR_MESSAGE "gi-marshalling-tests-gerror-message"
+
+void gi_marshalling_tests_gerror(GError **error);
+
 /* Overrides */
 
 #define GI_MARSHALLING_TESTS_OVERRIDES_CONSTANT 42
