@@ -148,6 +148,11 @@ regress_test_double (gdouble in)
   return in;
 }
 
+gunichar
+regress_test_unichar (gunichar in)
+{
+  return in;
+}
 
 time_t
 regress_test_timet (time_t in)
@@ -348,17 +353,6 @@ regress_test_utf8_nonconst_return (void)
   return g_strdup (utf8_nonconst);
 }
 
-/**
- * regress_test_utf8_nonconst_in:
- * @in: (transfer full): Accepted argument
- */
-void
-regress_test_utf8_nonconst_in (char *in)
-{
-  g_assert (strcmp (in, utf8_nonconst) == 0);
-  g_free(in);
-}
-
 /**
  * regress_test_utf8_const_in:
  *
@@ -390,7 +384,6 @@ regress_test_utf8_inout (char **inout)
 {
   /* inout parameter, transfer mode full */
   g_assert (strcmp (*inout, utf8_const) == 0);
-  g_free(*inout);
   *inout = g_strdup (utf8_nonconst);
 }
 
@@ -526,15 +519,16 @@ void
 regress_test_array_int_inout (int *n_ints, int **ints)
 {
   int i;
+  int *new_ints;
 
-  for (i = 1; i < *n_ints; i++) {
-	(*ints)[i-1] = (*ints)[i] + 1;
-  }
-
-  if (0 < *n_ints) {
-    *n_ints -= 1;
-  }
-  *ints = g_realloc(*ints, sizeof(**ints) * *n_ints);
+  if (0 < *n_ints)
+    {
+      *n_ints -= 1;
+      new_ints = g_malloc(sizeof(**ints) * *n_ints);
+      for (i = 0; i < *n_ints; i++)
+	new_ints[i] = (*ints)[i + 1] + 1;
+      *ints = new_ints;
+    }
 }
 
 /**
@@ -613,18 +607,6 @@ regress_test_strv_in (char **arr)
   return TRUE;
 }
 
-/**
- * regress_test_strv_in_container:
- * @arr: (array zero-terminated=1) (transfer container):
- */
-gboolean
-regress_test_strv_in_container (char **arr)
-{
-  gboolean result = regress_test_strv_in (arr);
-  g_free (arr);
-  return result;
-}
-
 /**
  * regress_test_array_gtype_in:
  * @n_types:
@@ -742,21 +724,6 @@ regress_test_array_fixed_size_int_return (void)
   return ints;
 }
 
-/**
- * regress_test_array_int_in_take:
- * @n_ints:
- * @ints: (array length=n_ints) (transfer full): List of ints
- */
-int
-regress_test_array_int_in_take (int n_ints, int *ints)
-{
-  int i, sum = 0;
-  for (i = 0; i < n_ints; i++)
-    sum += ints[i];
-  g_free (ints);
-  return sum;
-}
-
 /**
  * regress_test_strv_out_c:
  *
@@ -844,17 +811,6 @@ regress_test_sequence_list()
     return list;
 }
 
-/**
- * regress_test_glist_free:
- * @in: (element-type utf8) (transfer full):
- */
-void
-regress_test_glist_free (GList *in)
-{
-  g_list_foreach (in, (GFunc)g_free, NULL);
-  g_list_free (in);
-}
-
 /**
  * regress_test_glist_nothing_return:
  *
@@ -938,28 +894,6 @@ regress_test_glist_nothing_in2 (GList *in)
   regress_assert_test_sequence_list (in);
 }
 
-/**
- * regress_test_glist_container_in:
- * @in: (element-type utf8) (transfer container):
- */
-void
-regress_test_glist_container_in (GList *in)
-{
-  regress_assert_test_sequence_list (in);
-  g_list_free (in);
-}
-
-/**
- * regress_test_glist_everything_in:
- * @in: (element-type utf8) (transfer full):
- */
-void
-regress_test_glist_everything_in (GList *in)
-{
-  regress_assert_test_sequence_list (in);
-  regress_test_glist_free (in);
-}
-
 /**
  * regress_test_glist_null_in:
  * @in: (element-type utf8) (allow-none):
@@ -998,17 +932,6 @@ regress_test_sequence_slist()
     return list;
 }
 
-/**
- * regress_test_gslist_free:
- * @in: (element-type utf8) (transfer full):
- */
-void
-regress_test_gslist_free (GSList *in)
-{
-  g_slist_foreach (in, (GFunc)g_free, NULL);
-  g_slist_free (in);
-}
-
 /**
  * regress_test_gslist_nothing_return:
  *
@@ -1092,27 +1015,6 @@ regress_test_gslist_nothing_in2 (GSList *in)
   regress_assert_test_sequence_slist (in);
 }
 
-/**
- * regress_test_gslist_container_in:
- * @in: (element-type utf8) (transfer container):
- */
-void
-regress_test_gslist_container_in (GSList *in)
-{
-  regress_assert_test_sequence_slist (in);
-  g_slist_free (in);
-}
-
-/**
- * regress_test_gslist_everything_in:
- * @in: (element-type utf8) (transfer full):
- */
-void regress_test_gslist_everything_in (GSList *in)
-{
-  regress_assert_test_sequence_slist (in);
-  regress_test_gslist_free (in);
-}
-
 /**
  * regress_test_gslist_null_in:
  * @in: (element-type utf8) (allow-none):
@@ -1174,18 +1076,6 @@ regress_test_table_ghash_const()
   return hash;
 }
 
-/**
- * regress_test_ghash_free:
- * @in: (transfer full) (element-type utf8 utf8):
- */
-void
-regress_test_ghash_free (GHashTable *in)
-{
-  /* keys and values are deleted iff an appropriate element destroy function
-   * was registered */
-  g_hash_table_unref(in);
-}
-
 /**
  * regress_test_ghash_null_return:
  *
@@ -1296,43 +1186,6 @@ regress_test_ghash_nothing_in2 (GHashTable *in)
   assert_test_table_ghash (in);
 }
 
-/**
- * regress_test_ghash_container_in:
- * @in: (transfer container) (element-type utf8 utf8):
- */
-void
-regress_test_ghash_container_in (GHashTable *in)
-{
-  assert_test_table_ghash (in);
-  /* be careful and explicitly steal all the elements from the ghash before
-   * freeing it. */
-  g_hash_table_steal_all (in);
-  g_hash_table_destroy (in);
-}
-
-static gboolean
-ghash_freer(gpointer key, gpointer value, gpointer user_data)
-{
-  g_free(key);
-  g_free(value);
-  return TRUE;
-}
-
-/**
- * regress_test_ghash_everything_in:
- * @in: (transfer full) (element-type utf8 utf8):
- */
-void
-regress_test_ghash_everything_in (GHashTable *in)
-{
-  assert_test_table_ghash (in);
-  /* free the elements, then free the container.  Don't rely on the
-   * GHashTable's key/value destructor functions. */
-  g_hash_table_foreach_steal (in, ghash_freer, NULL);
-  /* okay, dealloc the hash table. */
-  g_hash_table_destroy (in);
-}
-
 /* Nested collection types */
 
 /**
@@ -1389,6 +1242,22 @@ regress_test_enum_get_type (void)
     return etype;
 }
 
+GType
+regress_test_enum_unsigned_get_type (void)
+{
+    static GType etype = 0;
+    if (G_UNLIKELY(etype == 0)) {
+        static const GEnumValue values[] = {
+            { REGRESS_TEST_UNSIGNED_VALUE1, "REGRESS_TEST_UNSIGNED_VALUE1", "value1" },
+            { REGRESS_TEST_UNSIGNED_VALUE2, "REGRESS_TEST_UNSIGNED_VALUE2", "value2" },
+            { 0, NULL, NULL }
+        };
+        etype = g_enum_register_static (g_intern_static_string ("RegressTestEnumUnsigned"), values);
+    }
+
+    return etype;
+}
+
 GType
 regress_test_flags_get_type (void)
 {
@@ -1419,6 +1288,30 @@ regress_test_enum_param(RegressTestEnum e)
   return ev->value_nick;
 }
 
+const gchar *
+regress_test_unsigned_enum_param(RegressTestEnumUnsigned e)
+{
+  GEnumValue *ev;
+  GEnumClass *ec;
+
+  ec = g_type_class_ref (regress_test_enum_unsigned_get_type ());
+  ev = g_enum_get_value (ec, e);
+  g_type_class_unref (ec);
+
+  return ev->value_nick;
+}
+
+/**
+ * regress_global_get_flags_out:
+ * @v: (out): A flags value
+ *
+ */
+void
+regress_global_get_flags_out (RegressTestFlags *v)
+{
+  *v = REGRESS_TEST_FLAG1 | REGRESS_TEST_FLAG3;
+}
+
 /* structures */
 
 /**
@@ -1801,6 +1694,7 @@ regress_test_obj_default_matrix (RegressTestObj *obj, const char *somestr)
 enum {
   REGRESS_TEST_OBJ_SIGNAL_SIG_NEW_WITH_ARRAY_PROP,
   REGRESS_TEST_OBJ_SIGNAL_SIG_WITH_HASH_PROP,
+  REGRESS_TEST_OBJ_SIGNAL_SIG_WITH_STRV,
   N_REGRESS_TEST_OBJ_SIGNALS
 };
 
@@ -1878,6 +1772,25 @@ regress_test_obj_class_init (RegressTestObjClass *klass)
 		  1,
 		  G_TYPE_HASH_TABLE);
 
+  /**
+   * RegressTestObj::sig-with-strv:
+   * @self: an object
+   * @strs: strings
+   *
+   * Test GStrv as a param.
+   */
+  regress_test_obj_signals[REGRESS_TEST_OBJ_SIGNAL_SIG_WITH_STRV] =
+    g_signal_new ("sig-with-strv",
+		  G_TYPE_FROM_CLASS (gobject_class),
+		  G_SIGNAL_RUN_LAST,
+		  0,
+		  NULL,
+		  NULL,
+		  g_cclosure_marshal_VOID__BOXED,
+		  G_TYPE_NONE,
+		  1,
+		  G_TYPE_STRV);
+
   gobject_class->set_property = regress_test_obj_set_property;
   gobject_class->get_property = regress_test_obj_get_property;
   gobject_class->dispose = regress_test_obj_dispose;
@@ -1996,6 +1909,16 @@ regress_test_obj_init (RegressTestObj *obj)
   obj->hash_table = NULL;
 }
 
+/**
+ * regress_test_obj_new: (constructor)
+ * @obj: A #RegressTestObj
+ */
+RegressTestObj *
+regress_test_obj_new (RegressTestObj *obj)
+{
+  return g_object_new (REGRESS_TEST_TYPE_OBJ, NULL);
+}
+
 /**
  * regress_test_obj_new_from_file:
  */
@@ -2031,6 +1954,16 @@ regress_test_obj_static_method (int x)
   return x;
 }
 
+/**
+ * regress_forced_method: (method)
+ * @obj: A #RegressTestObj
+ *
+ */
+void
+regress_forced_method (RegressTestObj *obj)
+{
+}
+
 /**
  * regress_test_obj_torture_signature_0:
  * @obj: A #RegressTestObj
@@ -2431,7 +2364,7 @@ regress_test_fundamental_sub_object_finalize (RegressTestFundamentalSubObject *
   g_return_if_fail (fundamental_sub_object != NULL);
 
   g_free(fundamental_sub_object->data);
-  regress_test_fundamental_object_unref (REGRESS_TEST_FUNDAMENTAL_OBJECT (fundamental_sub_object));
+  regress_test_fundamental_object_finalize (REGRESS_TEST_FUNDAMENTAL_OBJECT (fundamental_sub_object));
 }
 
 static void
@@ -2958,3 +2891,31 @@ regress_test_strv_in_gvalue (void)
 
   return value;
 }
+
+/**
+ * regress_introspectable_via_alias:
+ *
+ */
+void
+regress_introspectable_via_alias (RegressPtrArrayAlias *data)
+{
+}
+
+/**
+ * regress_not_introspectable_via_alias:
+ *
+ */
+void
+regress_not_introspectable_via_alias (RegressVaListAlias ok)
+{
+}
+
+/**
+ * regress_aliased_caller_alloc:
+ * @boxed: (out):
+ */
+void regress_aliased_caller_alloc (RegressAliasedTestBoxed *boxed)
+{
+  boxed->priv = g_slice_new0 (RegressTestBoxedPrivate);
+  boxed->priv->magic = 0xdeadbeef;
+}
