@@ -30,6 +30,7 @@ gssize regress_test_ssize (gssize in);
 gsize regress_test_size (gsize in);
 gfloat regress_test_float (gfloat in);
 gdouble regress_test_double (gdouble in);
+gunichar regress_test_unichar (gunichar in);
 time_t regress_test_timet (time_t in);
 GType regress_test_gtype (GType in);
 
@@ -136,9 +137,15 @@ typedef enum
 {
   REGRESS_TEST_VALUE1,
   REGRESS_TEST_VALUE2,
-  REGRESS_TEST_VALUE3 = 42
+  REGRESS_TEST_VALUE3 = -1
 } RegressTestEnum;
 
+typedef enum
+{
+  REGRESS_TEST_UNSIGNED_VALUE1 = 1,
+  REGRESS_TEST_UNSIGNED_VALUE2 = 0x80000000
+} RegressTestEnumUnsigned;
+
 typedef enum
 {
   REGRESS_TEST_FLAG1 = 1 << 0,
@@ -148,10 +155,15 @@ typedef enum
 
 GType regress_test_enum_get_type (void) G_GNUC_CONST;
 #define REGRESS_TEST_TYPE_ENUM (regress_test_enum_get_type ())
+GType regress_test_enum_unsigned_get_type (void) G_GNUC_CONST;
+#define REGRESS_TEST_TYPE_ENUM_UNSIGNED (regress_test_enum_unsigned_get_type ())
 GType regress_test_flags_get_type (void) G_GNUC_CONST;
 #define REGRESS_TEST_TYPE_FLAGS (regress_test_flags_get_type ())
 
 const gchar * regress_test_enum_param(RegressTestEnum e);
+const gchar * regress_test_unsigned_enum_param(RegressTestEnumUnsigned e);
+
+void regress_global_get_flags_out (RegressTestFlags *v);
 
 /* constants */
 
@@ -285,10 +297,12 @@ struct _RegressTestObjClass
 };
 
 GType      regress_test_obj_get_type (void);
+RegressTestObj*   regress_test_obj_new (RegressTestObj *obj);
 RegressTestObj*   regress_test_obj_new_from_file (const char *x, GError **error);
 void       regress_test_obj_set_bare (RegressTestObj *obj, GObject *bare);
 int        regress_test_obj_instance_method (RegressTestObj *obj);
 double     regress_test_obj_static_method (int x);
+void       regress_forced_method (RegressTestObj *obj);
 
 void regress_test_obj_torture_signature_0 (RegressTestObj    *obj,
                                    int        x,
@@ -549,6 +563,33 @@ typedef struct _RegressIntset RegressIntset;
  */
 typedef RegressIntset RegressIntSet;
 
+/**
+ * RegressPtrArrayAlias:
+ *
+ * Typedef'd GPtrArray for some reason
+ */
+typedef GPtrArray RegressPtrArrayAlias;
+
+void regress_introspectable_via_alias (RegressPtrArrayAlias *data);
+
+/**
+ * RegressVaListAlias:
+ *
+ * Typedef'd va_list for additional reasons
+ */
+typedef va_list RegressVaListAlias;
+
+void regress_not_introspectable_via_alias (RegressVaListAlias ok);
+
+/**
+ * RegressAliasedTestBoxed:
+ *
+ * Typedef TestBoxed to test caller-allocates correctness
+ */
+typedef RegressTestBoxed RegressAliasedTestBoxed;
+
+void regress_aliased_caller_alloc (RegressAliasedTestBoxed *boxed);
+
 /* private testing */
 
 typedef struct {
@@ -567,4 +608,6 @@ typedef enum {
   REGRESS_TEST_PUBLIC_ENUM_AFTER  = 1 << 2,
 } RegressTestPrivateEnum;
 
+#define REGRESS_UTF8_CONSTANT "const \xe2\x99\xa5 utf8"
+
 #endif /* __GITESTTYPES_H__ */
